@@ -169,8 +169,8 @@ impl PagerState {
             //
             // We reduce this from the number of available columns as this space cannot be used for
             // actual line display when wrapping the lines
-            let padding = len_line_number + usize::from(LineNumbers::EXTRA_PADDING);
-            let wrapped_lines = wrap_str(line, self.cols.saturating_sub(padding));
+            let padding = len_line_number + LineNumbers::EXTRA_PADDING;
+            let wrapped_lines = wrap_str(line, self.cols.saturating_sub(padding + 2));
             let mut formatted_rows = Vec::with_capacity(256);
 
             let first_line = {
@@ -183,14 +183,14 @@ impl PagerState {
                     // If a match is found, add this line's index to PagerState::search_idx
                     let (highlighted_row, is_match) = search::highlight_line_matches(&row, st);
                     if is_match {
-                        search_idx.insert(formatted_idx + 1);
+                        search_idx.insert(formatted_idx);
                     }
                     row = highlighted_row;
                 }
 
                 if cfg!(not(test)) {
                     format!(
-                        " {bold}{number: >len$}.{reset} {row}",
+                        "{bold}{number: >len$}.{reset} {row}",
                         bold = crossterm::style::Attribute::Bold,
                         number = idx + 1,
                         len = padding,
@@ -201,7 +201,7 @@ impl PagerState {
                     // In tests, we don't care about ANSI sequences for cool looking line numbers
                     // hence we don't include them in tests. It just makes testing more difficult
                     format!(
-                        " {number: >len$}. {row}",
+                        "{number: >len$}. {row}",
                         number = idx + 1,
                         len = padding,
                         row = row
@@ -228,7 +228,7 @@ impl PagerState {
                         }
                         row = highlighted_row;
                     }
-                    format!(" {row: >len$}", len = padding + 7, row = row)
+                    " ".repeat(padding + 2) + &row
                 })
                 .collect::<Vec<String>>();
             formatted_rows.append(&mut lines_left);
@@ -266,7 +266,7 @@ impl PagerState {
         // expensive
         let line_count = self.lines.lines().count();
 
-        // Calculate len_line_number. This will be 2 if line_count if 50 and 3 if line_count is 100.
+        // Calculate len_line_number. This will be 2 if line_count is 50 and 3 if line_count is 100 (etc)
         let len_line_number = line_count.to_string().len();
 
         // Search idx, this will get filled by the self.formatted_line function
